-----------------
HuggingFace agent
-----------------

.. literalinclude:: ../../../../../examples/user/huggingface_agent.py
    :caption: See `hugginface_agent.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/huggingface_agent.py>`_ on GitHub.

-----------------
HuggingFace datasets
-----------------

.. literalinclude:: ../../../../../examples/user/saving_prompts_as_hf_dataset.py
    :caption: See `saving_prompts_as_hf_dataset.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/saving_prompts_as_hf_dataset.py>`_ on GitHub.

-----------------
LangChain chains
-----------------

.. literalinclude:: ../../../../../examples/user/langchain_qa.py
    :caption: See `langchain_qa.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/langchain_qa.py>`_ on GitHub.

-----------------
LangChain generate
-----------------

.. literalinclude:: ../../../../../examples/user/langchain_generate.py
    :caption: See `langchain_generate.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/langchain_generate.py>`_ on GitHub.

-----------------
Pandas
-----------------

.. literalinclude:: ../../../../../examples/user/prompt_from_all_dataframe.py
    :caption: See `prompt_from_all_dataframe.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompt_from_all_dataframe.py>`_ on GitHub.

.. literalinclude:: ../../../../../examples/user/prompt_from_dataframe.py
    :caption: See `prompt_from_dataframe.py <https://github.com/IBM/ibm-generative-ai/blob/main/examples/user/prompt_from_dataframe.py>`_ on GitHub.
